@@ -10,8 +10,8 @@ from fastapi.responses import StreamingResponse
 from cameo_claw.cameo_claw import it_chunk
 
 from pydantic import BaseModel
-import polars as pl
-import pandas as pd
+
+from cameo_claw.cameo_claw_reuse import pd_read_csv
 
 app = FastAPI()
 app.add_middleware(CORSMiddleware,
@@ -49,10 +49,7 @@ async def it_streaming(i: ItemUrlFilter):
 
 def write_csv_header_to_gz(i):
     r = requests.get(i.lst_url[0], verify=False)
-    if i.lst_url[0][-3] == '.gz':
-        df = pd.read_csv(BytesIO(r.content), compression='gzip')
-    if i.lst_url[0][-4] == '.csv':
-        df = pd.read_csv(BytesIO(r.content))
+    df = pd_read_csv(r.content)
     bytesio_gz = BytesIO()
     with gzip.open(bytesio_gz, 'wb') as f:
         f.write((','.join(df.columns) + '\n').encode('utf-8'))
@@ -76,5 +73,5 @@ async def streaming_get(md5_hex):
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20430):
+def server(host='0.0.0.0', int_port=20432):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
